use strict;
use warnings;

use Test::NoWarnings;
use Test::Pod::Coverage 'tests' => 2;

# Test.
pod_coverage_ok('Wikibase::Datatype::Print::Value::Monolingual', 'Wikibase::Datatype::Print::Value::Monolingual is covered.');
